@@ -1,7 +1,7 @@
 p <- plotROC(SDMtune:::bm_maxent, test = SDMtune:::t)
 
 test_that("The plot contains the correct data", {
-  expect_equal(unique(p$data$set), c("Train", "Test"))
+  expect_setequal(unique(p$data$set), c("Train", "Test"))
   expect_equal(unique(p$data$pa), c(1, 0))
   expect_named(p$data, c("set", "pa", "pred"))
 
